package com.sun.xml.internal.ws.api.server;

import com.sun.istack.internal.NotNull;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;
import java.util.concurrent.CopyOnWriteArraySet;
import com.sun.xml.internal.ws.api.Component;
import java.util.Set;
import com.sun.xml.internal.ws.api.ComponentEx;
import com.sun.xml.internal.ws.api.ComponentRegistry;

public abstract class Container implements ComponentRegistry, ComponentEx
{
    private final Set<Component> components;
    public static final Container NONE;
    
    protected Container() {
        this.components = new CopyOnWriteArraySet();
    }
    
    public <S> S getSPI(Class<S> spiType) {
        if (this.components == null) {
            return null;
        }
        for (Component c : this.components) {
            S s = c.getSPI(spiType);
            if (s != null) {
                return s;
            }
            continue;
        }
        return null;
    }
    
    public Set<Component> getComponents() {
        return this.components;
    }
    
    @NotNull
    public <E> Iterable<E> getIterableSPI(Class<E> spiType) {
        E item = this.getSPI(spiType);
        if (item != null) {
            Collection<E> c = Collections.singletonList(item);
            return c;
        }
        return Collections.emptySet();
    }
    
    static {
        NONE = new Container.NoneContainer();
    }
    
    private static final class NoneContainer extends Container
    {
    }
}
